@@ -4,7 +4,7 @@
 |''Author:''|PaulDowney (psd (at) osmosoft (dot) com) |
 |''Source:''|http://whatfettle.com/2008/07/TiddlySpaceLinkPlugin/ |
 |''CodeRepository:''|http://svn.tiddlywiki.org/Trunk/contributors/PaulDowney/plugins/TiddlySpaceLinkPlugin/ |
-|''Version:''|1.2|
+|''Version:''|1.3|
 |''License:''|[[BSD License|http://www.opensource.org/licenses/bsd-license.php]] |
 |''Comments:''|Please make comments at http://groups.google.co.uk/group/TiddlyWikiDev |
 |''~CoreVersion:''|2.4|
@@ -38,7 +38,7 @@ Wikitext linking to a space on another server, for example from a tiddler in a s
 /*jslint onevar: false nomen: false plusplus: false */
 /*global jQuery config createTiddlyText createExternalLink createTiddlyLink */
 
-function createSpaceLink(place, spaceName, title, alt) {
+function createSpaceLink(place, spaceName, title, alt, isBag) {
 	var link, a, currentSpaceName;
 	try {
 		// seems safe to expect this to have been initialised within TiddlySpace
@@ -58,14 +58,23 @@ function createSpaceLink(place, spaceName, title, alt) {
 	}
 
 	// assumes a http URI without user:pass@ prefix
-	link = link.replace("http://", "http://" + spaceName.toLowerCase() + ".");
+	if(!isBag) {
+		link = link.replace("http://", "http://" + spaceName.toLowerCase() + ".");
+	} else {
+		link += "/bags/" + spaceName + "/tiddlers.wiki";
+	}
 
 	if (title) {
 		a = createExternalLink(place, link + "#" + encodeURIComponent(String.encodeTiddlyLink(title)), alt || title);
 	} else {
 		a = createExternalLink(place, link, alt || spaceName);
 	}
-	jQuery(a).addClass('tiddlySpaceLink').attr('tiddlyspace', spaceName).attr('tiddler', title);
+	jQuery(a).addClass('tiddlySpaceLink').attr('tiddler', title);
+	if(isBag) {
+		jQuery(a).attr('bag', spaceName);
+	} else {
+		jQuery(a).attr('tiddlyspace', spaceName);
+	}
 	return a;
 }
 
